@@ -25,6 +25,17 @@ use std::io::Write;
 /// This struct implements the `ModelWriter` trait to write a [Model](../atelier_core/model/struct.Model.html)
 /// in the [JSON AST](https://awslabs.github.io/smithy/1.0/spec/core/json-ast.html) representation.
 ///
+/// Currently the JSON writer takes only one parameter which determines whether the resulting JSON
+/// should be *pretty printed* or not, the default is `false`.
+///
+/// ```rust
+/// use atelier_json::JsonWriter;
+///
+/// let writer = JsonWriter::default(); // pretty printing off.
+///
+/// let writer = JsonWriter::new(true); // pretty printing on.
+/// ```
+///
 #[allow(missing_debug_implementations)]
 pub struct JsonWriter {
     pretty_print: bool,
@@ -36,7 +47,10 @@ pub struct JsonWriter {
 
 ///
 /// Return a [JSON AST](https://awslabs.github.io/smithy/1.0/spec/core/json-ast.html) representation
-/// of a model. This function is used in the `JsonWriter` implementation.
+/// of a model. The return value is a [Serde JSON/(https://docs.serde.rs/serde_json/) `Value` that
+/// represents the top-level model.
+///
+/// This function is used in the `JsonWriter` implementation.
 ///
 pub fn model_to_json(model: &Model) -> Value {
     let mut top: Map<String, Value> = Default::default();
@@ -46,6 +60,13 @@ pub fn model_to_json(model: &Model) -> Value {
         Value::String(model.smithy_version().to_string()),
     );
 
+    if model.has_metadata() {
+        let mut meta_map: Map<String, Value> = Default::default();
+        for (key, value) in model.metadata() {
+            let _ = meta_map.insert(key.to_string(), from_value(value));
+        }
+        let _ = top.insert(MODEL_METADATA.to_string(), Value::Object(meta_map));
+    }
     let _ = top.insert(MODEL_SHAPES.to_string(), from_shapes(model));
 
     Value::Object(top)
@@ -92,13 +113,6 @@ fn from_shapes(model: &Model) -> Value {
     for shape in model.shapes() {
         let _ = shape_map.insert(shape.id().to_string(), from_shape(shape));
     }
-    if model.has_metadata() {
-        let mut meta_map: Map<String, Value> = Default::default();
-        for (key, value) in model.metadata() {
-            let _ = meta_map.insert(key.to_string(), from_value(value));
-        }
-        let _ = shape_map.insert(MODEL_METADATA.to_string(), Value::Object(meta_map));
-    }
     Value::Object(shape_map)
 }
 
